Send Linux-ha-cvs mailing list submissions to
        [email protected]

To subscribe or unsubscribe via the World Wide Web, visit
        http://lists.community.tummy.com/mailman/listinfo/linux-ha-cvs
or, via email, send a message with subject or body 'help' to
        [EMAIL PROTECTED]

You can reach the person managing the list at
        [EMAIL PROTECTED]

When replying, please edit your Subject line so it is more specific
than "Re: Contents of Linux-ha-cvs digest..."


Today's Topics:

   1. Linux-HA CVS: fencing by sunjd from 
      ([email protected])


----------------------------------------------------------------------

Message: 1
Date: Mon, 21 Nov 2005 03:01:46 -0700 (MST)
From: [email protected]
Subject: [Linux-ha-cvs] Linux-HA CVS: fencing by sunjd from 
To: [EMAIL PROTECTED]
Message-ID: <[EMAIL PROTECTED]>

linux-ha CVS committal

Author  : sunjd
Host    : 
Project : linux-ha
Module  : fencing

Dir     : linux-ha/fencing/stonithd


Modified Files:
        stonithd.c 


Log Message:
shorted the time since some machine reboots quickly
===================================================================
RCS file: /home/cvs/linux-ha/linux-ha/fencing/stonithd/stonithd.c,v
retrieving revision 1.78
retrieving revision 1.79
diff -u -3 -r1.78 -r1.79
--- stonithd.c  19 Nov 2005 17:58:36 -0000      1.78
+++ stonithd.c  21 Nov 2005 10:01:44 -0000      1.79
@@ -1,4 +1,4 @@
-/* $Id: stonithd.c,v 1.78 2005/11/19 17:58:36 sunjd Exp $ */
+/* $Id: stonithd.c,v 1.79 2005/11/21 10:01:44 sunjd Exp $ */
 
 /* File: stonithd.c
  * Description: STONITH daemon for node fencing
@@ -1176,8 +1176,8 @@
        stonithd_log(LOG_DEBUG, "Got a notification of successfully resetting"
                " node %s from node %s with APITET.", target, from);    
 
-       /* The timeout value equals 2 minutes now */
-       timer_id = Gmain_timeout_add_full(G_PRIORITY_HIGH_IDLE, 120*1000
+       /* The timeout value equals 90 seconds now */
+       timer_id = Gmain_timeout_add_full(G_PRIORITY_HIGH_IDLE, 90*1000
                        , reboot_block_timeout, g_strdup(target), NULL);
 
        g_hash_table_replace(reboot_blocked_table, g_strdup(target)
@@ -3251,6 +3251,9 @@
 
 /* 
  * $Log: stonithd.c,v $
+ * Revision 1.79  2005/11/21 10:01:44  sunjd
+ * shorted the time since some machine reboots quickly
+ *
  * Revision 1.78  2005/11/19 17:58:36  sunjd
  * correct a typo found by Joachim Banzhaf
  *




------------------------------

_______________________________________________
Linux-ha-cvs mailing list
[email protected]
http://lists.community.tummy.com/mailman/listinfo/linux-ha-cvs


End of Linux-ha-cvs Digest, Vol 24, Issue 60
********************************************

Reply via email to